==> kibana-7.4.0-1-any.pkg.tar.xz: usr/share/kibana/src/core/public/index.js <==
"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
Object.defineProperty(exports, "ChromeBadge", {
  enumerable: true,
  get: function get() {
    return _chrome.ChromeBadge;
  }
});
Object.defineProperty(exports, "ChromeBrand", {
  enumerable: true,
  get: function get() {
    return _chrome.ChromeBrand;
  }
});
Object.defineProperty(exports, "ChromeBreadcrumb", {
  enumerable: true,
  get: function get() {
    return _chrome.ChromeBreadcrumb;
  }
});
Object.defineProperty(exports, "ChromeHelpExtension", {
  enumerable: true,
  get: function get() {
    return _chrome.ChromeHelpExtension;
  }
});
Object.defineProperty(exports, "ChromeNavControl", {
  enumerable: true,
  get: function get() {
    return _chrome.ChromeNavControl;
  }
});
Object.defineProperty(exports, "ChromeNavControls", {
  enumerable: true,
  get: function get() {
    return _chrome.ChromeNavControls;
  }
});
Object.defineProperty(exports, "ChromeNavLink", {
  enumerable: true,
  get: function get() {
    return _chrome.ChromeNavLink;
  }
});
Object.defineProperty(exports, "ChromeNavLinks", {
  enumerable: true,
  get: function get() {
    return _chrome.ChromeNavLinks;
  }
});
Object.defineProperty(exports, "ChromeNavLinkUpdateableFields", {
  enumerable: true,
  get: function get() {
    return _chrome.ChromeNavLinkUpdateableFields;
  }
});
Object.defineProperty(exports, "ChromeStart", {
  enumerable: true,
  get: function get() {
    return _chrome.ChromeStart;
  }
});
Object.defineProperty(exports, "ChromeRecentlyAccessed", {
  enumerable: true,
  get: function get() {
    return _chrome.ChromeRecentlyAccessed;
  }
});
Object.defineProperty(exports, "ChromeRecentlyAccessedHistoryItem", {
  enumerable: true,
  get: function get() {
    return _chrome.ChromeRecentlyAccessedHistoryItem;
  }
});
Object.defineProperty(exports, "FatalErrorsSetup", {
  enumerable: true,
  get: function get() {
    return _fatal_errors.FatalErrorsSetup;
  }
});
Object.defineProperty(exports, "FatalErrorInfo", {
  enumerable: true,
  get: function get() {
    return _fatal_errors.FatalErrorInfo;
  }
});
Object.defineProperty(exports, "HttpSetup", {
  enumerable: true,
  get: function get() {
    return _http.HttpSetup;
  }
});
Object.defineProperty(exports, "HttpStart", {
  enumerable: true,
  get: function get() {
    return _http.HttpStart;
  }
});
Object.defineProperty(exports, "HttpServiceBase", {
  enumerable: true,
  get: function get() {
    return _http.HttpServiceBase;
  }
});
Object.defineProperty(exports, "HttpHeadersInit", {
  enumerable: true,
  get: function get() {
    return _http.HttpHeadersInit;
  }
});
Object.defineProperty(exports, "HttpRequestInit", {
  enumerable: true,
  get: function get() {
    return _http.HttpRequestInit;
  }
});
Object.defineProperty(exports, "HttpFetchOptions", {
  enumerable: true,
  get: function get() {
    return _http.HttpFetchOptions;
  }
});
Object.defineProperty(exports, "HttpFetchQuery", {
  enumerable: true,
  get: function get() {
    return _http.HttpFetchQuery;
  }
});
Object.defineProperty(exports, "HttpErrorResponse", {
  enumerable: true,
  get: function get() {
    return _http.HttpErrorResponse;
  }
});
Object.defineProperty(exports, "HttpErrorRequest", {
  enumerable: true,
  get: function get() {
    return _http.HttpErrorRequest;
  }
});
Object.defineProperty(exports, "HttpInterceptor", {
  enumerable: true,
  get: function get() {
    return _http.HttpInterceptor;
  }
});
Object.defineProperty(exports, "HttpResponse", {
  enumerable: true,
  get: function get() {
    return _http.HttpResponse;
  }
});
Object.defineProperty(exports, "HttpHandler", {
  enumerable: true,
  get: function get() {
    return _http.HttpHandler;
  }
});
Object.defineProperty(exports, "HttpBody", {
  enumerable: true,
  get: function get() {
    return _http.HttpBody;
  }
});
Object.defineProperty(exports, "I18nStart", {
  enumerable: true,
  get: function get() {
    return _i18n.I18nStart;
  }
});
Object.defineProperty(exports, "LegacyNavLink", {
  enumerable: true,
  get: function get() {
    return _injected_metadata.LegacyNavLink;
  }
});
Object.defineProperty(exports, "ErrorToastOptions", {
  enumerable: true,
  get: function get() {
    return _notifications.ErrorToastOptions;
  }
});
Object.defineProperty(exports, "NotificationsSetup", {
  enumerable: true,
  get: function get() {
    return _notifications.NotificationsSetup;
  }
});
Object.defineProperty(exports, "NotificationsStart", {
  enumerable: true,
  get: function get() {
    return _notifications.NotificationsStart;
  }
});
Object.defineProperty(exports, "Toast", {
  enumerable: true,
  get: function get() {
    return _notifications.Toast;
  }
});
Object.defineProperty(exports, "ToastInput", {
  enumerable: true,
  get: function get() {
    return _notifications.ToastInput;
  }
});
Object.defineProperty(exports, "ToastsApi", {
  enumerable: true,
  get: function get() {
    return _notifications.ToastsApi;
  }
});
Object.defineProperty(exports, "OverlayStart", {
  enumerable: true,
  get: function get() {
    return _overlays.OverlayStart;
  }
});
Object.defineProperty(exports, "OverlayBannerMount", {
  enumerable: true,
  get: function get() {
    return _overlays.OverlayBannerMount;
  }
});
Object.defineProperty(exports, "OverlayBannerUnmount", {
  enumerable: true,
  get: function get() {
    return _overlays.OverlayBannerUnmount;
  }
});
Object.defineProperty(exports, "OverlayBannersStart", {
  enumerable: true,
  get: function get() {
    return _overlays.OverlayBannersStart;
  }
});
Object.defineProperty(exports, "OverlayRef", {
  enumerable: true,
  get: function get() {
    return _overlays.OverlayRef;
  }
});
Object.defineProperty(exports, "Plugin", {
  enumerable: true,
  get: function get() {
    return _plugins.Plugin;
  }
});
Object.defineProperty(exports, "PluginInitializer", {
  enumerable: true,
  get: function get() {
    return _plugins.PluginInitializer;
  }
});
Object.defineProperty(exports, "PluginInitializerContext", {
  enumerable: true,
  get: function get() {
    return _plugins.PluginInitializerContext;
  }
});
Object.defineProperty(exports, "PluginOpaqueId", {
  enumerable: true,
  get: function get() {
    return _plugins.PluginOpaqueId;
  }
});
Object.defineProperty(exports, "UiSettingsClient", {
  enumerable: true,
  get: function get() {
    return _ui_settings.UiSettingsClient;
  }
});
Object.defineProperty(exports, "UiSettingsState", {
  enumerable: true,
  get: function get() {
    return _ui_settings.UiSettingsState;
  }
});
Object.defineProperty(exports, "UiSettingsClientContract", {
  enumerable: true,
  get: function get() {
    return _ui_settings.UiSettingsClientContract;
  }
});
Object.defineProperty(exports, "ApplicationSetup", {
  enumerable: true,
  get: function get() {
    return _application.ApplicationSetup;
  }
});
Object.defineProperty(exports, "Capabilities", {
  enumerable: true,
  get: function get() {
    return _application.Capabilities;
  }
});
Object.defineProperty(exports, "ApplicationStart", {
  enumerable: true,
  get: function get() {
    return _application.ApplicationStart;
  }
});
Object.defineProperty(exports, "DocLinksStart", {
  enumerable: true,
  get: function get() {
    return _doc_links.DocLinksStart;
  }
});
Object.defineProperty(exports, "SavedObjectsStart", {
  enumerable: true,
  get: function get() {
    return _saved_objects.SavedObjectsStart;
  }
});
Object.defineProperty(exports, "SavedObjectsBatchResponse", {
  enumerable: true,
  get: function get() {
    return _saved_objects.SavedObjectsBatchResponse;
  }
});
Object.defineProperty(exports, "SavedObjectsBulkCreateObject", {
  enumerable: true,
  get: function get() {
    return _saved_objects.SavedObjectsBulkCreateObject;
  }
});
Object.defineProperty(exports, "SavedObjectsBulkCreateOptions", {
  enumerable: true,
  get: function get() {
    return _saved_objects.SavedObjectsBulkCreateOptions;
  }
});
Object.defineProperty(exports, "SavedObjectsCreateOptions", {
  enumerable: true,
  get: function get() {
    return _saved_objects.SavedObjectsCreateOptions;
  }
});
Object.defineProperty(exports, "SavedObjectsFindResponsePublic", {
  enumerable: true,
  get: function get() {
    return _saved_objects.SavedObjectsFindResponsePublic;
  }
});
Object.defineProperty(exports, "SavedObjectsUpdateOptions", {
  enumerable: true,
  get: function get() {
    return _saved_objects.SavedObjectsUpdateOptions;
  }
});
Object.defineProperty(exports, "SavedObject", {
  enumerable: true,
  get: function get() {
    return _saved_objects.SavedObject;
  }
});
Object.defineProperty(exports, "SavedObjectAttribute", {
  enumerable: true,
  get: function get() {
    return _saved_objects.SavedObjectAttribute;
  }
});
Object.defineProperty(exports, "SavedObjectAttributes", {
  enumerable: true,
  get: function get() {
    return _saved_objects.SavedObjectAttributes;
  }
});
Object.defineProperty(exports, "SavedObjectReference", {
  enumerable: true,
  get: function get() {
    return _saved_objects.SavedObjectReference;
  }
});
Object.defineProperty(exports, "SavedObjectsBaseOptions", {
  enumerable: true,
  get: function get() {
    return _saved_objects.SavedObjectsBaseOptions;
  }
});
Object.defineProperty(exports, "SavedObjectsFindOptions", {
  enumerable: true,
  get: function get() {
    return _saved_objects.SavedObjectsFindOptions;
  }
});
Object.defineProperty(exports, "SavedObjectsMigrationVersion", {
  enumerable: true,
  get: function get() {
    return _saved_objects.SavedObjectsMigrationVersion;
  }
});
Object.defineProperty(exports, "SavedObjectsClientContract", {
  enumerable: true,
  get: function get() {
    return _saved_objects.SavedObjectsClientContract;
  }
});
Object.defineProperty(exports, "SavedObjectsClient", {
  enumerable: true,
  get: function get() {
    return _saved_objects.SavedObjectsClient;
  }
});
Object.defineProperty(exports, "SimpleSavedObject", {
  enumerable: true,
  get: function get() {
    return _saved_objects.SimpleSavedObject;
  }
});
Object.defineProperty(exports, "IContextContainer", {
  enumerable: true,
  get: function get() {
    return _context.IContextContainer;
  }
});
Object.defineProperty(exports, "IContextProvider", {
  enumerable: true,
  get: function get() {
    return _context.IContextProvider;
  }
});
Object.defineProperty(exports, "ContextSetup", {
  enumerable: true,
  get: function get() {
    return _context.ContextSetup;
  }
});
Object.defineProperty(exports, "IContextHandler", {
  enumerable: true,
  get: function get() {
    return _context.IContextHandler;
  }
});
Object.defineProperty(exports, "CoreContext", {
  enumerable: true,
  get: function get() {
    return _core_system.CoreContext;
  }
});
Object.defineProperty(exports, "CoreSystem", {
  enumerable: true,
  get: function get() {
    return _core_system.CoreSystem;
  }
});
Object.defineProperty(exports, "RecursiveReadonly", {
  enumerable: true,
  get: function get() {
    return _utils.RecursiveReadonly;
  }
});

var _chrome = require("./chrome");

var _fatal_errors = require("./fatal_errors");

var _http = require("./http");

var _i18n = require("./i18n");

var _injected_metadata = require("./injected_metadata");

var _notifications = require("./notifications");

var _overlays = require("./overlays");

var _plugins = require("./plugins");

var _ui_settings = require("./ui_settings");

var _application = require("./application");

var _doc_links = require("./doc_links");

var _saved_objects = require("./saved_objects");

var _context = require("./context");

var _core_system = require("./core_system");

var _utils = require("../utils");

==> kibana-7.5.0-1-any.pkg.tar.xz: usr/share/kibana/src/core/public/index.js <==
"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
Object.defineProperty(exports, "ChromeBadge", {
  enumerable: true,
  get: function get() {
    return _chrome.ChromeBadge;
  }
});
Object.defineProperty(exports, "ChromeBrand", {
  enumerable: true,
  get: function get() {
    return _chrome.ChromeBrand;
  }
});
Object.defineProperty(exports, "ChromeBreadcrumb", {
  enumerable: true,
  get: function get() {
    return _chrome.ChromeBreadcrumb;
  }
});
Object.defineProperty(exports, "ChromeHelpExtension", {
  enumerable: true,
  get: function get() {
    return _chrome.ChromeHelpExtension;
  }
});
Object.defineProperty(exports, "ChromeNavControl", {
  enumerable: true,
  get: function get() {
    return _chrome.ChromeNavControl;
  }
});
Object.defineProperty(exports, "ChromeNavControls", {
  enumerable: true,
  get: function get() {
    return _chrome.ChromeNavControls;
  }
});
Object.defineProperty(exports, "ChromeNavLink", {
  enumerable: true,
  get: function get() {
    return _chrome.ChromeNavLink;
  }
});
Object.defineProperty(exports, "ChromeNavLinks", {
  enumerable: true,
  get: function get() {
    return _chrome.ChromeNavLinks;
  }
});
Object.defineProperty(exports, "ChromeNavLinkUpdateableFields", {
  enumerable: true,
  get: function get() {
    return _chrome.ChromeNavLinkUpdateableFields;
  }
});
Object.defineProperty(exports, "ChromeStart", {
  enumerable: true,
  get: function get() {
    return _chrome.ChromeStart;
  }
});
Object.defineProperty(exports, "ChromeRecentlyAccessed", {
  enumerable: true,
  get: function get() {
    return _chrome.ChromeRecentlyAccessed;
  }
});
Object.defineProperty(exports, "ChromeRecentlyAccessedHistoryItem", {
  enumerable: true,
  get: function get() {
    return _chrome.ChromeRecentlyAccessedHistoryItem;
  }
});
Object.defineProperty(exports, "FatalErrorsSetup", {
  enumerable: true,
  get: function get() {
    return _fatal_errors.FatalErrorsSetup;
  }
});
Object.defineProperty(exports, "FatalErrorInfo", {
  enumerable: true,
  get: function get() {
    return _fatal_errors.FatalErrorInfo;
  }
});
Object.defineProperty(exports, "HttpSetup", {
  enumerable: true,
  get: function get() {
    return _http.HttpSetup;
  }
});
Object.defineProperty(exports, "HttpStart", {
  enumerable: true,
  get: function get() {
    return _http.HttpStart;
  }
});
Object.defineProperty(exports, "HttpServiceBase", {
  enumerable: true,
  get: function get() {
    return _http.HttpServiceBase;
  }
});
Object.defineProperty(exports, "HttpHeadersInit", {
  enumerable: true,
  get: function get() {
    return _http.HttpHeadersInit;
  }
});
Object.defineProperty(exports, "HttpRequestInit", {
  enumerable: true,
  get: function get() {
    return _http.HttpRequestInit;
  }
});
Object.defineProperty(exports, "HttpFetchOptions", {
  enumerable: true,
  get: function get() {
    return _http.HttpFetchOptions;
  }
});
Object.defineProperty(exports, "HttpFetchQuery", {
  enumerable: true,
  get: function get() {
    return _http.HttpFetchQuery;
  }
});
Object.defineProperty(exports, "HttpErrorResponse", {
  enumerable: true,
  get: function get() {
    return _http.HttpErrorResponse;
  }
});
Object.defineProperty(exports, "HttpErrorRequest", {
  enumerable: true,
  get: function get() {
    return _http.HttpErrorRequest;
  }
});
Object.defineProperty(exports, "HttpInterceptor", {
  enumerable: true,
  get: function get() {
    return _http.HttpInterceptor;
  }
});
Object.defineProperty(exports, "HttpResponse", {
  enumerable: true,
  get: function get() {
    return _http.HttpResponse;
  }
});
Object.defineProperty(exports, "HttpHandler", {
  enumerable: true,
  get: function get() {
    return _http.HttpHandler;
  }
});
Object.defineProperty(exports, "HttpBody", {
  enumerable: true,
  get: function get() {
    return _http.HttpBody;
  }
});
Object.defineProperty(exports, "IBasePath", {
  enumerable: true,
  get: function get() {
    return _http.IBasePath;
  }
});
Object.defineProperty(exports, "IHttpInterceptController", {
  enumerable: true,
  get: function get() {
    return _http.IHttpInterceptController;
  }
});
Object.defineProperty(exports, "IHttpFetchError", {
  enumerable: true,
  get: function get() {
    return _http.IHttpFetchError;
  }
});
Object.defineProperty(exports, "I18nStart", {
  enumerable: true,
  get: function get() {
    return _i18n.I18nStart;
  }
});
Object.defineProperty(exports, "LegacyNavLink", {
  enumerable: true,
  get: function get() {
    return _injected_metadata.LegacyNavLink;
  }
});
Object.defineProperty(exports, "NotificationsSetup", {
  enumerable: true,
  get: function get() {
    return _notifications.NotificationsSetup;
  }
});
Object.defineProperty(exports, "NotificationsStart", {
  enumerable: true,
  get: function get() {
    return _notifications.NotificationsStart;
  }
});
Object.defineProperty(exports, "Toast", {
  enumerable: true,
  get: function get() {
    return _notifications.Toast;
  }
});
Object.defineProperty(exports, "ToastInput", {
  enumerable: true,
  get: function get() {
    return _notifications.ToastInput;
  }
});
Object.defineProperty(exports, "IToasts", {
  enumerable: true,
  get: function get() {
    return _notifications.IToasts;
  }
});
Object.defineProperty(exports, "ToastsApi", {
  enumerable: true,
  get: function get() {
    return _notifications.ToastsApi;
  }
});
Object.defineProperty(exports, "ToastInputFields", {
  enumerable: true,
  get: function get() {
    return _notifications.ToastInputFields;
  }
});
Object.defineProperty(exports, "ToastsSetup", {
  enumerable: true,
  get: function get() {
    return _notifications.ToastsSetup;
  }
});
Object.defineProperty(exports, "ToastsStart", {
  enumerable: true,
  get: function get() {
    return _notifications.ToastsStart;
  }
});
Object.defineProperty(exports, "ErrorToastOptions", {
  enumerable: true,
  get: function get() {
    return _notifications.ErrorToastOptions;
  }
});
Object.defineProperty(exports, "OverlayStart", {
  enumerable: true,
  get: function get() {
    return _overlays.OverlayStart;
  }
});
Object.defineProperty(exports, "OverlayBannerMount", {
  enumerable: true,
  get: function get() {
    return _overlays.OverlayBannerMount;
  }
});
Object.defineProperty(exports, "OverlayBannerUnmount", {
  enumerable: true,
  get: function get() {
    return _overlays.OverlayBannerUnmount;
  }
});
Object.defineProperty(exports, "OverlayBannersStart", {
  enumerable: true,
  get: function get() {
    return _overlays.OverlayBannersStart;
  }
});
Object.defineProperty(exports, "OverlayRef", {
  enumerable: true,
  get: function get() {
    return _overlays.OverlayRef;
  }
});
Object.defineProperty(exports, "Plugin", {
  enumerable: true,
  get: function get() {
    return _plugins.Plugin;
  }
});
Object.defineProperty(exports, "PluginInitializer", {
  enumerable: true,
  get: function get() {
    return _plugins.PluginInitializer;
  }
});
Object.defineProperty(exports, "PluginInitializerContext", {
  enumerable: true,
  get: function get() {
    return _plugins.PluginInitializerContext;
  }
});
Object.defineProperty(exports, "PluginOpaqueId", {
  enumerable: true,
  get: function get() {
    return _plugins.PluginOpaqueId;
  }
});
Object.defineProperty(exports, "UiSettingsClient", {
  enumerable: true,
  get: function get() {
    return _ui_settings.UiSettingsClient;
  }
});
Object.defineProperty(exports, "UiSettingsState", {
  enumerable: true,
  get: function get() {
    return _ui_settings.UiSettingsState;
  }
});
Object.defineProperty(exports, "UiSettingsClientContract", {
  enumerable: true,
  get: function get() {
    return _ui_settings.UiSettingsClientContract;
  }
});
Object.defineProperty(exports, "ApplicationSetup", {
  enumerable: true,
  get: function get() {
    return _application.ApplicationSetup;
  }
});
Object.defineProperty(exports, "Capabilities", {
  enumerable: true,
  get: function get() {
    return _application.Capabilities;
  }
});
Object.defineProperty(exports, "ApplicationStart", {
  enumerable: true,
  get: function get() {
    return _application.ApplicationStart;
  }
});
Object.defineProperty(exports, "App", {
  enumerable: true,
  get: function get() {
    return _application.App;
  }
});
Object.defineProperty(exports, "AppBase", {
  enumerable: true,
  get: function get() {
    return _application.AppBase;
  }
});
Object.defineProperty(exports, "AppUnmount", {
  enumerable: true,
  get: function get() {
    return _application.AppUnmount;
  }
});
Object.defineProperty(exports, "AppMountContext", {
  enumerable: true,
  get: function get() {
    return _application.AppMountContext;
  }
});
Object.defineProperty(exports, "AppMountParameters", {
  enumerable: true,
  get: function get() {
    return _application.AppMountParameters;
  }
});
Object.defineProperty(exports, "DocLinksStart", {
  enumerable: true,
  get: function get() {
    return _doc_links.DocLinksStart;
  }
});
Object.defineProperty(exports, "SavedObjectsStart", {
  enumerable: true,
  get: function get() {
    return _saved_objects.SavedObjectsStart;
  }
});
Object.defineProperty(exports, "SavedObjectsBatchResponse", {
  enumerable: true,
  get: function get() {
    return _saved_objects.SavedObjectsBatchResponse;
  }
});
Object.defineProperty(exports, "SavedObjectsBulkCreateObject", {
  enumerable: true,
  get: function get() {
    return _saved_objects.SavedObjectsBulkCreateObject;
  }
});
Object.defineProperty(exports, "SavedObjectsBulkCreateOptions", {
  enumerable: true,
  get: function get() {
    return _saved_objects.SavedObjectsBulkCreateOptions;
  }
});
Object.defineProperty(exports, "SavedObjectsCreateOptions", {
  enumerable: true,
  get: function get() {
    return _saved_objects.SavedObjectsCreateOptions;
  }
});
Object.defineProperty(exports, "SavedObjectsFindResponsePublic", {
  enumerable: true,
  get: function get() {
    return _saved_objects.SavedObjectsFindResponsePublic;
  }
});
Object.defineProperty(exports, "SavedObjectsUpdateOptions", {
  enumerable: true,
  get: function get() {
    return _saved_objects.SavedObjectsUpdateOptions;
  }
});
Object.defineProperty(exports, "SavedObject", {
  enumerable: true,
  get: function get() {
    return _saved_objects.SavedObject;
  }
});
Object.defineProperty(exports, "SavedObjectAttribute", {
  enumerable: true,
  get: function get() {
    return _saved_objects.SavedObjectAttribute;
  }
});
Object.defineProperty(exports, "SavedObjectAttributes", {
  enumerable: true,
  get: function get() {
    return _saved_objects.SavedObjectAttributes;
  }
});
Object.defineProperty(exports, "SavedObjectAttributeSingle", {
  enumerable: true,
  get: function get() {
    return _saved_objects.SavedObjectAttributeSingle;
  }
});
Object.defineProperty(exports, "SavedObjectReference", {
  enumerable: true,
  get: function get() {
    return _saved_objects.SavedObjectReference;
  }
});
Object.defineProperty(exports, "SavedObjectsBaseOptions", {
  enumerable: true,
  get: function get() {
    return _saved_objects.SavedObjectsBaseOptions;
  }
});
Object.defineProperty(exports, "SavedObjectsFindOptions", {
  enumerable: true,
  get: function get() {
    return _saved_objects.SavedObjectsFindOptions;
  }
});
Object.defineProperty(exports, "SavedObjectsMigrationVersion", {
  enumerable: true,
  get: function get() {
    return _saved_objects.SavedObjectsMigrationVersion;
  }
});
Object.defineProperty(exports, "SavedObjectsClientContract", {
  enumerable: true,
  get: function get() {
    return _saved_objects.SavedObjectsClientContract;
  }
});
Object.defineProperty(exports, "SavedObjectsClient", {
  enumerable: true,
  get: function get() {
    return _saved_objects.SavedObjectsClient;
  }
});
Object.defineProperty(exports, "SimpleSavedObject", {
  enumerable: true,
  get: function get() {
    return _saved_objects.SimpleSavedObject;
  }
});
Object.defineProperty(exports, "PackageInfo", {
  enumerable: true,
  get: function get() {
    return _types.PackageInfo;
  }
});
Object.defineProperty(exports, "EnvironmentMode", {
  enumerable: true,
  get: function get() {
    return _types.EnvironmentMode;
  }
});
Object.defineProperty(exports, "IContextContainer", {
  enumerable: true,
  get: function get() {
    return _context.IContextContainer;
  }
});
Object.defineProperty(exports, "IContextProvider", {
  enumerable: true,
  get: function get() {
    return _context.IContextProvider;
  }
});
Object.defineProperty(exports, "ContextSetup", {
  enumerable: true,
  get: function get() {
    return _context.ContextSetup;
  }
});
Object.defineProperty(exports, "HandlerFunction", {
  enumerable: true,
  get: function get() {
    return _context.HandlerFunction;
  }
});
Object.defineProperty(exports, "HandlerContextType", {
  enumerable: true,
  get: function get() {
    return _context.HandlerContextType;
  }
});
Object.defineProperty(exports, "HandlerParameters", {
  enumerable: true,
  get: function get() {
    return _context.HandlerParameters;
  }
});
Object.defineProperty(exports, "CoreContext", {
  enumerable: true,
  get: function get() {
    return _core_system.CoreContext;
  }
});
Object.defineProperty(exports, "CoreSystem", {
  enumerable: true,
  get: function get() {
    return _core_system.CoreSystem;
  }
});
Object.defineProperty(exports, "RecursiveReadonly", {
  enumerable: true,
  get: function get() {
    return _utils.RecursiveReadonly;
  }
});

var _chrome = require("./chrome");

var _fatal_errors = require("./fatal_errors");

var _http = require("./http");

var _i18n = require("./i18n");

var _injected_metadata = require("./injected_metadata");

var _notifications = require("./notifications");

var _overlays = require("./overlays");

var _plugins = require("./plugins");

var _ui_settings = require("./ui_settings");

var _application = require("./application");

var _doc_links = require("./doc_links");

var _saved_objects = require("./saved_objects");

var _types = require("../server/types");

var _context = require("./context");

var _core_system = require("./core_system");

var _utils = require("../utils");
